@@ -86,7 +86,11 @@ import com.openexchange.mailfilter.internal.MailFilterProperties;
  */
 public class SieveHandler {
 
-    /**
+    private static final Pattern LITERAL_S2C_PATTERN = Pattern.compile("^.*\\{([^\\}]*)\\}.*$");
+
+    private static final Pattern STRING_PATTERN = Pattern.compile("^.*\"([^\"]*)\".*$");
+
+	/**
      * The logger.
      */
     private static Log log = com.openexchange.log.Log.valueOf(LogFactory.getLog(SieveHandler.class));
@@ -301,7 +305,7 @@ public class SieveHandler {
                 } else if (temp.startsWith(SIEVE_OK)) {
                     break;
                 } else if (temp.startsWith(SIEVE_AUTH_FAILED)) {
-                    throw new OXSieveHandlerException("can't auth to SIEVE ", sieve_host, sieve_host_port, parseSIEVEResponse(temp));
+                    throw new OXSieveHandlerException("can't auth to SIEVE ", sieve_host, sieve_host_port, parseSIEVEResponse(temp, null));
                 }
             }
             /*
@@ -391,36 +395,18 @@ public class SieveHandler {
         bos_sieve.write(CRLF.getBytes(com.openexchange.java.Charsets.UTF_8));
         bos_sieve.flush();
 
-        final StringBuilder sb = new StringBuilder();
         final String actualline = bis_sieve.readLine();
         if (null != actualline && actualline.startsWith(SIEVE_OK)) {
             return;
         } else if (null != actualline && actualline.startsWith("NO ")) {
-            final String answer = actualline.substring(3);
-            final Pattern p = Pattern.compile("^\\{([^\\}]*)\\}.*$");
-            final Matcher matcher = p.matcher(answer);
-            if (matcher.matches()) {
-                final String group = matcher.group(1);
-                final int octetsToRead = Integer.parseInt(group);
-                final char[] buf = new char[octetsToRead];
-                final int octetsRead = bis_sieve.read(buf, 0, octetsToRead);
-                if (octetsRead == octetsToRead) {
-                    sb.append(buf);
-                } else {
-                    sb.append(buf, 0, octetsRead);
-                }
-                sb.append(CRLF);
-            } else {
-                sb.append(answer);
-                sb.append(CRLF);
-            }
-            throw new OXSieveHandlerException(sb.toString(), sieve_host, sieve_host_port, null);
+            final String errorMessage = parseError(actualline).replaceAll(CRLF, "\n");
+            throw new OXSieveHandlerException(errorMessage, sieve_host, sieve_host_port, parseSIEVEResponse(actualline, errorMessage));
         } else {
-            throw new OXSieveHandlerException("Unknown error occured", sieve_host, sieve_host_port, parseSIEVEResponse(actualline));
+            throw new OXSieveHandlerException("Unknown response code", sieve_host, sieve_host_port, parseSIEVEResponse(actualline, null));
         }
     }
 
-    /**
+	/**
      * Activate/Deactivate sieve script. Is status is true, activate this script.
      *
      * @param script_name
@@ -477,11 +463,11 @@ public class SieveHandler {
             }
             final int[] parsed = parseFirstLine(firstLine);
             final int respCode = parsed[0];
-            if (NO == respCode || OK == respCode) {
-                /*
-                 * Either received a NO or an OK which indicates end of response. In both cases no script is availabe.
-                 */
+            if (OK == respCode) {
                 return "";
+            } else if (NO == respCode) {
+                final String errorMessage = parseError(firstLine).replaceAll(CRLF, "\n");
+                throw new OXSieveHandlerException(errorMessage, sieve_host, sieve_host_port, parseSIEVEResponse(firstLine, errorMessage));
             }
             sb.ensureCapacity(parsed[1]);
         }
@@ -554,7 +540,7 @@ public class SieveHandler {
                 return list;
             }
             if (temp.startsWith(SIEVE_NO)) {
-                throw new OXSieveHandlerException("Sieve has no script list", sieve_host, sieve_host_port, parseSIEVEResponse(temp));
+                throw new OXSieveHandlerException("Sieve has no script list", sieve_host, sieve_host_port, parseSIEVEResponse(temp, null));
             }
             // Here we strip off the leading and trailing " and the ACTIVE at the
             // end if it occurs. We want a list of the script names only
@@ -567,7 +553,7 @@ public class SieveHandler {
     /**
      * Get the list of active sieve scripts
      *
-     * @return List of scripts
+     * @return List of scripts, or null if no script is active
      * @throws IOException
      * @throws UnsupportedEncodingException
      * @throws OXSieveHandlerException
@@ -591,7 +577,7 @@ public class SieveHandler {
                 return scriptname;
             }
             if (temp.startsWith(SIEVE_NO)) {
-                throw new OXSieveHandlerException("Sieve has no script list", sieve_host, sieve_host_port, parseSIEVEResponse(temp));
+                throw new OXSieveHandlerException("Sieve has no script list", sieve_host, sieve_host_port, parseSIEVEResponse(temp, null));
             }
 
             if (temp.matches(".*ACTIVE")) {
@@ -635,7 +621,7 @@ public class SieveHandler {
             if (temp.startsWith(SIEVE_OK)) {
                 return;
             } else if (temp.startsWith(SIEVE_NO)) {
-                throw new OXSieveHandlerException("Script can't be removed", sieve_host, sieve_host_port, parseSIEVEResponse(temp));
+                throw new OXSieveHandlerException("Script can't be removed", sieve_host, sieve_host_port, parseSIEVEResponse(temp, null));
             }
         }
     }
@@ -668,7 +654,7 @@ public class SieveHandler {
                 return true;
             } else if (test.startsWith(SIEVE_NO)) {
                 AUTH = false;
-                throw new OXSieveHandlerException("Communication to SIEVE server aborted. ", sieve_host, sieve_host_port, parseSIEVEResponse(test));
+                throw new OXSieveHandlerException("Communication to SIEVE server aborted. ", sieve_host, sieve_host_port, parseSIEVEResponse(test, null));
             } else {
                 parseCAPA(test);
             }
@@ -823,7 +809,7 @@ public class SieveHandler {
             if (temp.endsWith(SIEVE_AUTH_LOGIN_USERNAME)) {
                 break;
             } else if (temp.endsWith(SIEVE_AUTH_FAILED)) {
-                throw new OXSieveHandlerException("can't auth to SIEVE ", sieve_host, sieve_host_port, parseSIEVEResponse(temp));
+                throw new OXSieveHandlerException("can't auth to SIEVE ", sieve_host, sieve_host_port, parseSIEVEResponse(temp, null));
             }
         }
 
@@ -845,7 +831,7 @@ public class SieveHandler {
             if (temp.endsWith(SIEVE_AUTH_LOGIN_PASSWORD)) {
                 break;
             } else if (temp.endsWith(SIEVE_AUTH_FAILED)) {
-                throw new OXSieveHandlerException("can't auth to SIEVE ", sieve_host, sieve_host_port, parseSIEVEResponse(temp));
+                throw new OXSieveHandlerException("can't auth to SIEVE ", sieve_host, sieve_host_port, parseSIEVEResponse(temp, null));
             }
         }
 
@@ -868,18 +854,29 @@ public class SieveHandler {
                 AUTH = true;
                 return true;
             } else if (temp.startsWith(SIEVE_AUTH_FAILED)) {
-                throw new OXSieveHandlerException("can't auth to SIEVE ", sieve_host, sieve_host_port, parseSIEVEResponse(temp));
+                throw new OXSieveHandlerException("can't auth to SIEVE ", sieve_host, sieve_host_port, parseSIEVEResponse(temp, null));
             }
         }
     }
 
+    /**
+     * Old method for compatibility reasons
+     *
+     * @deprecated use {@link #parseSIEVEResponse(String, String)} instead
+     */
+   @Deprecated
+   protected SIEVEResponse.Code parseSIEVEResponse(final String resp) {
+       return parseSIEVEResponse(resp, null);
+   }
+
     /**
      * Parse the https://tools.ietf.org/html/rfc5804#section-1.3 Response code of a SIEVE
      * response line.
+     * @param multiline TODO
      * @param response line
      * @return null, if no response code in line, the @{SIEVEResponse.Code} otherwise.
      */
-    protected SIEVEResponse.Code parseSIEVEResponse(final String resp) {
+    protected SIEVEResponse.Code parseSIEVEResponse(final String resp, final String multiline) {
         if( ! useSIEVEResponseCodes ) {
             return null;
         }
@@ -890,7 +887,14 @@ public class SieveHandler {
             final int gcount = m.groupCount();
             if( gcount > 1 ) {
                 final SIEVEResponse.Code ret = SIEVEResponse.Code.getCode(m.group(1));
-                ret.setMessage(m.group(2));
+                final String group = m.group(2);
+                if (group.startsWith("{")) {
+                	// Multi line, use the multiline parsed before here
+                	ret.setMessage(multiline);
+                } else {
+                	// Single line
+                	ret.setMessage(group);
+                }
                 return ret;
             }
         }
@@ -917,7 +921,7 @@ public class SieveHandler {
             if (temp.startsWith(SIEVE_OK)) {
                 return;
             } else if (temp.startsWith(SIEVE_NO)) {
-                throw new OXSieveHandlerException("Error while activating script: " + sieve_script_name, sieve_host, sieve_host_port, parseSIEVEResponse(temp));
+                throw new OXSieveHandlerException("Error while activating script: " + sieve_script_name, sieve_host, sieve_host_port, parseSIEVEResponse(temp, null));
             }
         }
     }
@@ -944,7 +948,7 @@ public class SieveHandler {
                 if (temp.startsWith(SIEVE_OK)) {
                     return;
                 } else if (temp.startsWith(SIEVE_NO)) {
-                    throw new OXSieveHandlerException("Error while deactivating script: " + sieve_script_name, sieve_host, sieve_host_port, parseSIEVEResponse(temp));
+                    throw new OXSieveHandlerException("Error while deactivating script: " + sieve_script_name, sieve_host, sieve_host_port, parseSIEVEResponse(temp, null));
                 }
             }
         }
@@ -1025,7 +1029,38 @@ public class SieveHandler {
     }
 
     /**
-     * COnverts given string to Base64 using given charset encoding.
+     * Parses and gets the error text. Note this will be CRLF terminated.
+     * 
+     * @param actualline
+     * @return
+     * @throws IOException
+     * @throws OXSieveHandlerException 
+     */
+    private String parseError(final String actualline) throws IOException, OXSieveHandlerException {
+        final StringBuilder sb = new StringBuilder();
+        final String answer = actualline.substring(3);
+        final Matcher matcher = LITERAL_S2C_PATTERN.matcher(answer);
+        final Matcher stringMatcher = STRING_PATTERN.matcher(answer);
+        if (matcher.matches()) {
+            final String group = matcher.group(1);
+            final int octetsToRead = Integer.parseInt(group);
+            final char[] buf = new char[octetsToRead];
+            final int octetsRead = bis_sieve.read(buf, 0, octetsToRead);
+            if (octetsRead == octetsToRead) {
+                sb.append(buf);
+            } else {
+                sb.append(buf, 0, octetsRead);
+            }
+        } else if (stringMatcher.matches()) {
+            sb.append(stringMatcher.group(1));
+        } else {
+            throw new OXSieveHandlerException("Unable to parse server answer", sieve_host, sieve_host_port, null);
+        }
+        return sb.toString();
+    }
+
+    /**
+     * Converts given string to Base64 using given charset encoding.
      *
      * @param toConvert The string to convert to Base64
      * @param charset The charset encoding to use when retrieving bytes from passed string
