@@ -280,19 +280,23 @@ public class MailfilterAction extends AbstractAction<Rule, MailfilterRequest> {
             try {
                 handlerConnect(sieveHandler);
                 final String activeScript = sieveHandler.getActiveScript();
-                final String script = sieveHandler.getScript(activeScript);
-                final RuleListAndNextUid rulesandid = sieveTextFilter.readScriptFromString(script);
-                final ClientRulesAndRequire clientrulesandrequire =
-                    sieveTextFilter.splitClientRulesAndRequire(rulesandid.getRulelist(), null, rulesandid.isError());
-                final String body = request.getBody();
-                final JSONObject json = new JSONObject(body);
+                if (null != activeScript) {
+                    final String script = sieveHandler.getScript(activeScript);
+                    final RuleListAndNextUid rulesandid = sieveTextFilter.readScriptFromString(script);
+                    final ClientRulesAndRequire clientrulesandrequire =
+                        sieveTextFilter.splitClientRulesAndRequire(rulesandid.getRulelist(), null, rulesandid.isError());
+                    final String body = request.getBody();
+                    final JSONObject json = new JSONObject(body);
 
-                final ArrayList<Rule> rules = clientrulesandrequire.getRules();
-                final RuleAndPosition deletedrule =
-                    getRightRuleForUniqueId(rules, getUniqueId(json), credentials.getRightUsername(), credentials.getContextString());
-                rules.remove(deletedrule.getPosition());
-                final String writeback = sieveTextFilter.writeback(clientrulesandrequire, new HashSet<String>(sieveHandler.getCapabilities().getSieve()));
-                writeScript(sieveHandler, activeScript, writeback);
+                    final ArrayList<Rule> rules = clientrulesandrequire.getRules();
+                    final RuleAndPosition deletedrule =
+                        getRightRuleForUniqueId(rules, getUniqueId(json), credentials.getRightUsername(), credentials.getContextString());
+                    rules.remove(deletedrule.getPosition());
+                    final String writeback = sieveTextFilter.writeback(clientrulesandrequire, new HashSet<String>(sieveHandler.getCapabilities().getSieve()));
+                    writeScript(sieveHandler, activeScript, writeback);
+                } else {
+                    throw OXMailfilterExceptionCode.NO_ACTIVE_SCRIPT.create();
+                }
             } catch (final UnsupportedEncodingException e) {
                 throw OXMailfilterExceptionCode.UNSUPPORTED_ENCODING.create(e, EMPTY_ARGS);
             } catch (final IOException e) {
@@ -346,21 +350,29 @@ public class MailfilterAction extends AbstractAction<Rule, MailfilterRequest> {
             final SieveHandler sieveHandler = connectRight(credentials);
             try {
                 handlerConnect(sieveHandler);
-                final String script = sieveHandler.getScript(sieveHandler.getActiveScript());
-                if (log.isDebugEnabled()) {
-                    log.debug("The following sieve script will be parsed:\n" + script);
+                final String activeScript = sieveHandler.getActiveScript();
+                final String script;
+                if (null != activeScript) {
+                    script = sieveHandler.getScript(activeScript);
+                } else {
+                    script = "";
                 }
-                final RuleListAndNextUid readScriptFromString = sieveTextFilter.readScriptFromString(script);
-                final ClientRulesAndRequire clientrulesandrequire =
-                    sieveTextFilter.splitClientRulesAndRequire(
+                if (log.isDebugEnabled()) {
+                    log.debug("The following sieve script will be parsed:\n"
+                        + script);
+                }
+                final RuleListAndNextUid readScriptFromString = sieveTextFilter
+                    .readScriptFromString(script);
+                final ClientRulesAndRequire clientrulesandrequire = sieveTextFilter
+                    .splitClientRulesAndRequire(
                         readScriptFromString.getRulelist(),
                         parameters.getParameter(Parameter.FLAG),
                         readScriptFromString.isError());
-                final ArrayList<Rule> clientrules = clientrulesandrequire.getRules();
-
+                final ArrayList<Rule> clientrules = clientrulesandrequire
+                    .getRules();
                 changeOutgoingVacationRule(clientrules);
-
-                return CONVERTER.write(clientrules.toArray(new Rule[clientrules.size()]));
+                return CONVERTER.write(clientrules
+                    .toArray(new Rule[clientrules.size()]));
             } catch (final UnsupportedEncodingException e) {
                 throw OXMailfilterExceptionCode.UNSUPPORTED_ENCODING.create(e, EMPTY_ARGS);
             } catch (final IOException e) {
@@ -414,7 +426,12 @@ public class MailfilterAction extends AbstractAction<Rule, MailfilterRequest> {
             try {
                 handlerConnect(sieveHandler);
                 final String activeScript = sieveHandler.getActiveScript();
-                final String script = sieveHandler.getScript(activeScript);
+                final String script;
+                if (null != activeScript) {
+                    script = sieveHandler.getScript(activeScript);
+                } else {
+                    script = "";
+                }
                 final RuleListAndNextUid rules = sieveTextFilter.readScriptFromString(script);
 
                 final ClientRulesAndRequire clientrulesandrequire =
@@ -473,7 +490,7 @@ public class MailfilterAction extends AbstractAction<Rule, MailfilterRequest> {
             } catch (final ParseException e) {
                 throw OXMailfilterExceptionCode.SIEVE_ERROR.create(e, e.getMessage());
             } catch (final SieveException e) {
-                throw OXMailfilterExceptionCode.SIEVE_ERROR.create(e, e.getMessage());
+                throw handleSieveException(e);
             } catch (final JSONException e) {
                 throw OXJSONExceptionCodes.JSON_READ_ERROR.create(e, e.getMessage());
             } catch (final TokenMgrError error) {
@@ -507,32 +524,35 @@ public class MailfilterAction extends AbstractAction<Rule, MailfilterRequest> {
             try {
                 handlerConnect(sieveHandler);
                 final String activeScript = sieveHandler.getActiveScript();
-                final String script = sieveHandler.getScript(activeScript);
-                final RuleListAndNextUid rules = sieveTextFilter.readScriptFromString(script);
+                if (null != activeScript) {
+                    final String script = sieveHandler.getScript(activeScript);
+                    final RuleListAndNextUid rules = sieveTextFilter.readScriptFromString(script);
 
-                final ClientRulesAndRequire clientrulesandrequire =
-                    sieveTextFilter.splitClientRulesAndRequire(rules.getRulelist(), null, rules.isError());
+                    final ClientRulesAndRequire clientrulesandrequire =
+                        sieveTextFilter.splitClientRulesAndRequire(rules.getRulelist(), null, rules.isError());
 
-                final String body = request.getBody();
-                final JSONArray json = new JSONArray(body);
+                    final String body = request.getBody();
+                    final JSONArray json = new JSONArray(body);
 
-                final ArrayList<Rule> clientrules = clientrulesandrequire.getRules();
-                for (int i = 0; i < json.length(); i++) {
-                    final int uniqueid = json.getInt(i);
-                    final RuleAndPosition rightRule =
-                        getRightRuleForUniqueId(
-                            clientrules,
-                            Integer.valueOf(uniqueid),
-                            credentials.getRightUsername(),
-                            credentials.getContextString());
-                    final int position = rightRule.getPosition();
-                    clientrules.remove(position);
-                    clientrules.add(i, rightRule.getRule());
+                    final ArrayList<Rule> clientrules = clientrulesandrequire.getRules();
+                    for (int i = 0; i < json.length(); i++) {
+                        final int uniqueid = json.getInt(i);
+                        final RuleAndPosition rightRule =
+                            getRightRuleForUniqueId(
+                                clientrules,
+                                Integer.valueOf(uniqueid),
+                                credentials.getRightUsername(),
+                                credentials.getContextString());
+                        final int position = rightRule.getPosition();
+                        clientrules.remove(position);
+                        clientrules.add(i, rightRule.getRule());
+                    }
+
+                    final String writeback = sieveTextFilter.writeback(clientrulesandrequire, new HashSet<String>(sieveHandler.getCapabilities().getSieve()));
+                    writeScript(sieveHandler, activeScript, writeback);
+                } else {
+                    throw OXMailfilterExceptionCode.NO_ACTIVE_SCRIPT.create();
                 }
-
-                final String writeback = sieveTextFilter.writeback(clientrulesandrequire, new HashSet<String>(sieveHandler.getCapabilities().getSieve()));
-                writeScript(sieveHandler, activeScript, writeback);
-
             } catch (final UnsupportedEncodingException e) {
                 throw OXMailfilterExceptionCode.UNSUPPORTED_ENCODING.create(e, EMPTY_ARGS);
             } catch (final IOException e) {
@@ -585,33 +605,41 @@ public class MailfilterAction extends AbstractAction<Rule, MailfilterRequest> {
             final SieveHandler sieveHandler = connectRight(credentials);
             try {
                 handlerConnect(sieveHandler);
-                final String activeScript = fixParsingError(sieveHandler.getActiveScript());
-                final String script = fixParsingError(sieveHandler.getScript(activeScript));
-                final RuleListAndNextUid rules = sieveTextFilter.readScriptFromString(script);
-
-                final ClientRulesAndRequire clientrulesandrequire =
-                    sieveTextFilter.splitClientRulesAndRequire(rules.getRulelist(), null, rules.isError());
-
-                final String body = request.getBody();
-                final JSONObject json = new JSONObject(body);
-                final Integer uniqueid = getUniqueId(json);
-
-                final ArrayList<Rule> clientrules = clientrulesandrequire.getRules();
-                if (null == uniqueid) {
-                    throw OXMailfilterExceptionCode.ID_MISSING.create();
+                final String activeScript = sieveHandler.getActiveScript();
+                if (null != activeScript) {
+                    final String script = fixParsingError(sieveHandler
+                        .getScript(activeScript));
+                    final RuleListAndNextUid rules = sieveTextFilter
+                        .readScriptFromString(script);
+                    final ClientRulesAndRequire clientrulesandrequire = sieveTextFilter
+                        .splitClientRulesAndRequire(rules.getRulelist(),
+                            null, rules.isError());
+                    final String body = request.getBody();
+                    final JSONObject json = new JSONObject(body);
+                    final Integer uniqueid = getUniqueId(json);
+                    final ArrayList<Rule> clientrules = clientrulesandrequire
+                        .getRules();
+                    if (null == uniqueid) {
+                        throw OXMailfilterExceptionCode.ID_MISSING.create();
+                    }
+                    // First get the right rule which should be modified...
+                    final RuleAndPosition rightRule = getRightRuleForUniqueId(
+                        clientrules, uniqueid,
+                        credentials.getRightUsername(),
+                        credentials.getContextString());
+                    CONVERTER.parse(rightRule.getRule(), json);
+                    changeIncomingVacationRule(rightRule.getRule());
+                    final String writeback = sieveTextFilter.writeback(
+                        clientrulesandrequire, new HashSet<String>(
+                            sieveHandler.getCapabilities().getSieve()));
+                    if (log.isDebugEnabled()) {
+                        log.debug("The following sieve script will be written:\n"
+                            + writeback);
+                    }
+                    writeScript(sieveHandler, activeScript, writeback);
+                } else {
+                    throw OXMailfilterExceptionCode.NO_ACTIVE_SCRIPT.create();
                 }
-                // First get the right rule which should be modified...
-                final RuleAndPosition rightRule =
-                    getRightRuleForUniqueId(clientrules, uniqueid, credentials.getRightUsername(), credentials.getContextString());
-                CONVERTER.parse(rightRule.getRule(), json);
-                changeIncomingVacationRule(rightRule.getRule());
-
-                final String writeback = sieveTextFilter.writeback(clientrulesandrequire, new HashSet<String>(sieveHandler.getCapabilities().getSieve()));
-                if (log.isDebugEnabled()) {
-                    log.debug("The following sieve script will be written:\n" + writeback);
-                }
-                writeScript(sieveHandler, activeScript, writeback);
-
             } catch (final UnsupportedEncodingException e) {
                 throw OXMailfilterExceptionCode.UNSUPPORTED_ENCODING.create(e, EMPTY_ARGS);
             } catch (final IOException e) {
@@ -623,7 +651,7 @@ public class MailfilterAction extends AbstractAction<Rule, MailfilterRequest> {
             } catch (final ParseException e) {
                 throw OXMailfilterExceptionCode.SIEVE_ERROR.create(e, e.getMessage());
             } catch (final SieveException e) {
-                throw OXMailfilterExceptionCode.SIEVE_ERROR.create(e, e.getMessage());
+                throw handleSieveException(e);
             } catch (final JSONException e) {
                 throw OXJSONExceptionCodes.JSON_BUILD_ERROR.create(e, EMPTY_ARGS);
             } catch (final TokenMgrError error) {
@@ -700,7 +728,11 @@ public class MailfilterAction extends AbstractAction<Rule, MailfilterRequest> {
             try {
                 handlerConnect(sieveHandler);
                 final String activeScript = sieveHandler.getActiveScript();
-                return sieveHandler.getScript(activeScript);
+                if (null != activeScript) {
+                    return sieveHandler.getScript(activeScript);
+                } else {
+                    return "";
+                }
             } catch (final UnsupportedEncodingException e) {
                 throw OXMailfilterExceptionCode.UNSUPPORTED_ENCODING.create(e, EMPTY_ARGS);
             } catch (final IOException e) {
@@ -978,6 +1010,19 @@ public class MailfilterAction extends AbstractAction<Rule, MailfilterRequest> {
         throw OXMailfilterExceptionCode.NO_SUCH_ID.create(uniqueid, userName, contextStr);
     }
 
+    private static OXException handleSieveException(final SieveException e) {
+        final String msg = e.getMessage();
+        final OXException ret = OXMailfilterExceptionCode.SIEVE_ERROR.create(e, msg);
+        if (null != msg) {
+            if (msg.startsWith(OXMailfilterExceptionCode.ERR_PREFIX_REJECTED_ADDRESS)) {
+                ret.setCategory(Category.CATEGORY_USER_INPUT);
+            } else if (msg.startsWith(OXMailfilterExceptionCode.ERR_PREFIX_INVALID_ADDRESS)) {
+                ret.setCategory(Category.CATEGORY_USER_INPUT);
+            }
+        }
+        return ret;
+    }
+
     // private int getIndexOfRightRuleForUniqueId(final ArrayList<Rule>
     // clientrules, Integer uniqueid) throws OXException {
     // for (int i = 0; i < clientrules.size(); i++) {
